{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 2,
                    "ramMin": 500,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "quay.io/biocontainers/seqprep:1.1--1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "label": "first read input fastq",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#seqprep.cwl/forward_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep.cwl/namefile"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "label": "second read input fastq",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#seqprep.cwl/reverse_reads"
                }
            ],
            "baseCommand": "SeqPrep",
            "arguments": [
                "-1",
                "forward_unmerged.fastq.gz",
                "-2",
                "reverse_unmerged.fastq.gz",
                {
                    "valueFrom": "${ return inputs.namefile.nameroot.split('_')[0] + '_MERGED.fastq.gz' }\n",
                    "prefix": "-s"
                }
            ],
            "doc": "SeqPrep is a program to merge paired end Illumina reads that are overlapping into a single longer read. It may also just be used for its adapter trimming feature without doing any paired end overlap. When an adapter sequence is present, that means that the two reads must overlap (in most cases) so they are forcefully merged. When reads do not have adapter sequence they must be treated with care when doing the merging, so a much more specific approach is taken. The default parameters were chosen with specificity in mind, so that they could be ran on libraries where very few reads are expected to overlap. It is always safest though to save the overlapping procedure for libraries where you have some prior knowledge that a significant portion of the reads will have some overlap.\n",
            "label": "Tool for stripping adaptors and/or merging paired reads with overlap into single reads.",
            "id": "#seqprep.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.forward_reads.format)",
                    "outputBinding": {
                        "glob": "forward_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "$(inputs.forward_reads.format)",
                    "outputBinding": {
                        "glob": "*_MERGED*"
                    },
                    "id": "#seqprep.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "$(inputs.forward_reads.format)",
                    "outputBinding": {
                        "glob": "reverse_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/reverse_unmerged_reads"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/trimmomatic:0.36--6"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMax": 16384,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "trimmomatic.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "label": "minimum average quality required",
                    "doc": "Drop the read if the average quality is below the specified level\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "label": "read cropping",
                    "doc": "Removes bases regardless of quality from the end of the read, so that the read has maximally the specified length after this step has been performed. Steps performed after CROP might of course further shorten the read. The value is the number of bases to keep, from the start of the read.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/crop"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": "read -end mode format",
                    "doc": "Single End (SE) or Paired End (PE) mode\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "label": "read head trimming",
                    "doc": "Removes the specified number of bases, regardless of quality, from the beginning of the read. The numbser specified is the number of bases to keep, from the start of the read.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/headcrop"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if ( self ) {\n     return \"ILLUMINACLIP:\" + inputs.illuminaClip.adapters.path + \":\"\n       + self.seedMismatches + \":\" + self.palindromeClipThreshold + \":\"\n       + self.simpleClipThreshold + \":\" + self.minAdapterLength + \":\"\n       + self.keepBothReads;\n   } else {\n     return self;\n   }\n }\n",
                        "position": 11
                    },
                    "label": "sequencing adaptater removing",
                    "doc": "Cut adapter and other illumina-specific sequences from the read.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/illuminaClip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list (e.g. \"-Xms128m -Xmx512m\")\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "label": "read tail trimming",
                    "doc": "Remove low quality bases from the beginning. As long as a base has a value below this threshold the base is removed and the next base will be investigated.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"MAXINFO:\" + self.targetLength + \":\" + self.strictness;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "label": "maxinfo: read score quality filtering",
                    "doc": "Performs an adaptive quality trim, balancing the benefits of retaining longer reads against the costs of retaining bases with errors. <targetLength>: This specifies the read length which is likely to allow the location of the read within the target sequence to be determined. <strictness>: This value, which should be set between 0 and 1, specifies the balance between preserving as much read length as possible vs. removal of incorrect bases. A low value of this parameter (<0.2) favours longer reads, while a high value (>0.8) favours read correctness.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "label": "minimum length read filter",
                    "doc": "This module removes reads that fall below the specified minimal length. If required, it should normally be after all other processing steps. Reads removed by this step will be counted and included in the \"dropped reads\" count presented in the trimmomatic summary.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/minlen"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "label": "quality score format",
                    "doc": "Either PHRED \"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/phred"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "label": "FASTQ read file 1",
                    "doc": "FASTQ file of reads (R1 reads in Paired End mode)\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "label": "FASTQ read file 2",
                    "doc": "FASTQ file of R2 reads in Paired End mode\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads2"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "SLIDINGWINDOW:",
                        "separate": false
                    },
                    "label": "read filtering sliding window",
                    "doc": "Perform a sliding window trimming, cutting once the average quality within the window falls below a threshold. By considering multiple bases, a single poor quality base will not cause the removal of high quality data later in the read. <windowSize> specifies the number of bases to average across <requiredQuality> specifies the average quality required\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "label": "quality score conversion to phred33",
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "label": "quality score conversion to phred64",
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "label": "read tail quality filtering",
                    "doc": "Remove low quality bases from the end. As long as a base has a value below this threshold the base is removed and the next base (which as trimmomatic is starting from the 3' prime end would be base preceding the just removed base) will be investigated. This approach can be used removing the special Illumina \"low quality segment\" regions (which are marked with quality score of 2), but we recommend Sliding Window or MaxInfo instead\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/trailing"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trim.log"
                    },
                    "label": "Log file",
                    "doc": "log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n",
                    "id": "#Trimmomatic-v0.36-SE.cwl/log_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed"
                    },
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads1_trimmed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.basename).trimmed.unpaired.fastq"
                    },
                    "id": "#Trimmomatic-v0.36-SE.cwl/reads1_trimmed_unpaired"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "trim.log",
                    "prefix": "-trimlog",
                    "position": 4
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 4,
                    "prefix": "-threads"
                },
                {
                    "valueFrom": "$(inputs.reads1.nameroot).trimmed",
                    "position": 7
                }
            ],
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop Illumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem depending on the library preparation and downstream application. There are two major modes of the program: Paired end mode and Single end mode. The paired end mode will maintain correspondence of read pairs and also use the additional information contained in paired reads to better find adapter or PCR primer fragments introduced by the library preparation process. Trimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores, depending on the Illumina pipeline used).\n",
            "label": "Trimmomatic - A flexible read trimming tool for Illumina NGS data",
            "id": "#Trimmomatic-v0.36-SE.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Quality control filtering step using the BioPython package.",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "run_quality_filtering.py"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#qc-filtering.cwl/input_file_format"
                },
                {
                    "type": "int",
                    "default": 100,
                    "label": "Minimum read or contig length",
                    "doc": "Specify the minimum read or contig length for sequences to pass QC filtering.\n",
                    "id": "#qc-filtering.cwl/min_length"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "Trimmed sequence file",
                    "doc": "Trimmed and FASTQ to FASTA converted sequences file.\n",
                    "id": "#qc-filtering.cwl/seq_file"
                },
                {
                    "type": "string",
                    "default": "stats_summary",
                    "label": "Post QC stats output file name",
                    "doc": "Give a name for the file which will hold the stats after QC.\n",
                    "id": "#qc-filtering.cwl/stats_file_name"
                },
                {
                    "type": "int",
                    "label": "Number of submitted sequences",
                    "doc": "Number of originally submitted sequences as in the user submitted FASTQ file - single end FASTQ or pair end merged FASTQ file.\n",
                    "id": "#qc-filtering.cwl/submitted_seq_count"
                }
            ],
            "outputs": [
                {
                    "label": "Filtered output file",
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.seq_file.nameroot).fasta"
                    },
                    "id": "#qc-filtering.cwl/filtered_file"
                },
                {
                    "label": "Stats summary output file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.stats_file_name)"
                    },
                    "id": "#qc-filtering.cwl/stats_summary_file"
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(inputs.seq_file.nameroot).fasta"
                },
                {
                    "position": 3,
                    "valueFrom": "$(inputs.stats_file_name)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.submitted_seq_count)"
                },
                {
                    "position": 5,
                    "prefix": "--min_length",
                    "valueFrom": "$(inputs.min_length)"
                },
                {
                    "position": 6,
                    "prefix": "--extension",
                    "valueFrom": "$(inputs.input_file_format)"
                }
            ],
            "id": "#qc-filtering.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Post QC-ed input analysis of sequence file",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "qc-stats:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$({class: 'Directory', listing: []})",
                            "entryname": "$(inputs.out_dir_name)",
                            "writable": true
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 900,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "MGRAST_base.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#qc-stats.cwl/QCed_reads"
                },
                {
                    "label": "Prefix for the files associated with GC distribution",
                    "type": "string",
                    "default": "GC-distribution.out",
                    "id": "#qc-stats.cwl/gc_sum"
                },
                {
                    "label": "Prefix for the files assocaited with sequence length distribution",
                    "type": "string",
                    "default": "seq-length.out",
                    "id": "#qc-stats.cwl/length_sum"
                },
                {
                    "label": "Maximum number of sequences to sub-sample",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000000,
                    "id": "#qc-stats.cwl/max_seq"
                },
                {
                    "label": "Prefix for the files associated with nucleotide distribution",
                    "type": "string",
                    "default": "nucleotide-distribution.out",
                    "id": "#qc-stats.cwl/nucleotide_distribution"
                },
                {
                    "label": "Specifies output subdirectory",
                    "type": "string",
                    "default": "qc-statistics",
                    "id": "#qc-stats.cwl/out_dir_name"
                },
                {
                    "label": "Specifies the number of sequences in the input read file (FASTA formatted)",
                    "type": "int",
                    "id": "#qc-stats.cwl/sequence_count"
                },
                {
                    "label": "File names for summary of sequences, e.g. number, min/max length etc.",
                    "type": "string",
                    "default": "summary.out",
                    "id": "#qc-stats.cwl/summary"
                }
            ],
            "outputs": [
                {
                    "label": "Contains all stats output files",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)"
                    },
                    "id": "#qc-stats.cwl/output_dir"
                },
                {
                    "label": "Contains the summary statistics for the input sequence file",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)/$(inputs.summary)"
                    },
                    "id": "#qc-stats.cwl/summary_out"
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "prefix": "-o",
                    "valueFrom": "$(inputs.out_dir_name)/$(inputs.summary)"
                },
                {
                    "position": 2,
                    "prefix": "-d",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.nucleotide_distribution, suffix);\n}\n"
                },
                {
                    "position": 3,
                    "prefix": "-g",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.gc_sum, suffix);\n}\n"
                },
                {
                    "position": 4,
                    "prefix": "-l",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.length_sum, suffix);\n}\n"
                },
                {
                    "position": 5,
                    "valueFrom": "${ if (inputs.sequence_count > inputs.max_seq) { return '-m '.concat(inputs.max_seq)} else { return ''} }"
                }
            ],
            "id": "#qc-stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Replaces problematic characters from FASTA headers with dashes",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "tr",
                "\" /|<_;#\"",
                "-------"
            ],
            "stdout": "$(inputs.sequences.nameroot).unfiltered_fasta",
            "outputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences_with_cleaned_headers",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.nameroot).unfiltered_fasta"
                    }
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#clean_fasta_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "grep",
                "-c",
                "^>"
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#count_fasta.cwl/number"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count_fasta.cwl/sequences"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "|",
                    "position": 2,
                    "shellQuote": false
                },
                {
                    "valueFrom": "cat",
                    "shellQuote": false,
                    "position": 3
                }
            ],
            "stdout": "grepcount",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "grepcount",
                        "loadContents": true,
                        "outputEval": "${\n  var grep_count = parseInt(self[0].contents) || 0;\n  if (grep_count === 0) {\n    return 0;\n  } else {\n    return parseInt(grep_count / inputs.number);\n  }\n}\n"
                    },
                    "id": "#count_fasta.cwl/count"
                }
            ],
            "id": "#count_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 2,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "count_lines.py"
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "id": "#count_lines.cwl/number"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#count_lines.cwl/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "data.txt",
                        "loadContents": true,
                        "outputEval": "$(parseInt(self[0].contents))"
                    },
                    "id": "#count_lines.cwl/count"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#count_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "doc": "Modified from https://github.com/nigyta/bact_genome/blob/master/cwl/tool/fastp/fastp.cwl\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 8,
                    "ramMin": 3800,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "fastp"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--correction"
                    },
                    "id": "#fastp.cwl/base_correction"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--disable_trim_poly_g"
                    },
                    "id": "#fastp.cwl/disable_trim_poly_g"
                },
                {
                    "type": "File",
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929"
                    ],
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#fastp.cwl/fastq1"
                },
                {
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929"
                    ],
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "id": "#fastp.cwl/fastq2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--trim_poly_g"
                    },
                    "id": "#fastp.cwl/force_polyg_tail_trimming"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 50,
                    "inputBinding": {
                        "prefix": "--length_required"
                    },
                    "id": "#fastp.cwl/min_length_required"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "prefix": "--qualified_quality_phred"
                    },
                    "id": "#fastp.cwl/qualified_phred_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--thread"
                    },
                    "id": "#fastp.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "prefix": "--unqualified_percent_limit"
                    },
                    "id": "#fastp.cwl/unqualified_phred_quality"
                }
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(inputs.fastq1.nameroot).fastp.fastq"
                },
                "${\n  if (inputs.fastq2){\n    return '-O';\n  } else {\n    return '';\n  }\n}\n",
                "${\n  if (inputs.fastq2){\n    return inputs.fastq2.nameroot + \".fastp.fastq\";\n  } else {\n    return '';\n  }\n}\n"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "fastp.html"
                    },
                    "id": "#fastp.cwl/html_report"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "fastp.json"
                    },
                    "id": "#fastp.cwl/json_report"
                },
                {
                    "type": "File",
                    "format": "$(inputs.fastq1.format)",
                    "outputBinding": {
                        "glob": "$(inputs.fastq1.nameroot).fastp.fastq"
                    },
                    "id": "#fastp.cwl/out_fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "$(inputs.fastq2.format)",
                    "outputBinding": {
                        "glob": "$(inputs.fastq2.nameroot).fastp.fastq"
                    },
                    "id": "#fastp.cwl/out_fastq2"
                }
            ],
            "id": "#fastp.cwl",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 300,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "biopython/biopython:latest",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#fastq_to_fasta.cwl/fastq"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.fastq.nameroot).unclean",
                    "prefix": "-o"
                }
            ],
            "baseCommand": [
                "fastq_to_fasta.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "*.unclean"
                    },
                    "id": "#fastq_to_fasta.cwl/fasta"
                }
            ],
            "id": "#fastq_to_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "id": "#generate_checksum.cwl/input_file"
                }
            ],
            "baseCommand": [
                "generate_checksum.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*sha1"
                    },
                    "id": "#generate_checksum.cwl/hashsum"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#generate_checksum.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "unzip files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 2000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                },
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "gunzip"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "is this an assembly file?",
                    "id": "#multiple-gunzip.cwl/assembly"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "label": "for seqprep result: unmerged forward seqprep output or single end reads",
                    "id": "#multiple-gunzip.cwl/forward_unmerged_reads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "are these raw reads or amplicon reads?",
                    "id": "#multiple-gunzip.cwl/reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": " unmerged reverse seqprep output",
                    "id": "#multiple-gunzip.cwl/reverse_unmerged_reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "merged seq prep output",
                    "id": "#multiple-gunzip.cwl/target_reads"
                }
            ],
            "baseCommand": [
                "gunzip",
                "-c"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.target_reads.format)",
                    "id": "#multiple-gunzip.cwl/unzipped_file",
                    "outputBinding": {
                        "glob": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }"
                    }
                }
            ],
            "stdout": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }",
            "id": "#multiple-gunzip.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "output QC-FAILED or QC-PASSED file as intermediate flag",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#qc-flag.cwl/qc_count"
                }
            ],
            "baseCommand": [
                "touch"
            ],
            "arguments": [
                {
                    "valueFrom": "${ var flag = \"\"; if (inputs.qc_count == 0) { flag = 'QC-FAILED'; } else { flag = 'QC-PASSED'; } return flag; }"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "QC-*"
                    },
                    "id": "#qc-flag.cwl/qc-flag"
                }
            ],
            "id": "#qc-flag.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/forward_reads"
                },
                {
                    "type": "int",
                    "id": "#main/qc_min_length"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/reverse_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/single_reads"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/overlap_reads/fastp_report",
                    "id": "#main/fastp_filtering_json"
                },
                {
                    "type": "File",
                    "outputSource": "#main/length_filter/filtered_file",
                    "id": "#main/filtered_fasta"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputSource": "#main/hashsum_paired/hashsum",
                    "pickValue": "all_non_null",
                    "id": "#main/input_files_hashsum_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/hashsum_single/hashsum",
                    "id": "#main/input_files_hashsum_single"
                },
                {
                    "type": "File",
                    "outputSource": "#main/clean_fasta_headers/sequences_with_cleaned_headers",
                    "id": "#main/motus_input"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/qc_stats/output_dir",
                    "id": "#main/qc-statistics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/QC-FLAG/qc-flag",
                    "id": "#main/qc-status"
                },
                {
                    "type": "File",
                    "outputSource": "#main/length_filter/stats_summary_file",
                    "id": "#main/qc_summary"
                }
            ],
            "steps": [
                {
                    "run": "#qc-flag.cwl",
                    "in": [
                        {
                            "source": "#main/count_processed_reads/count",
                            "id": "#main/QC-FLAG/qc_count"
                        }
                    ],
                    "out": [
                        "#main/QC-FLAG/qc-flag"
                    ],
                    "id": "#main/QC-FLAG"
                },
                {
                    "run": "#clean_fasta_headers.cwl",
                    "in": [
                        {
                            "source": "#main/trim_quality_control/reads1_trimmed",
                            "id": "#main/clean_fasta_headers/sequences"
                        }
                    ],
                    "out": [
                        "#main/clean_fasta_headers/sequences_with_cleaned_headers"
                    ],
                    "id": "#main/clean_fasta_headers"
                },
                {
                    "run": "#fastq_to_fasta.cwl",
                    "in": [
                        {
                            "source": "#main/clean_fasta_headers/sequences_with_cleaned_headers",
                            "id": "#main/convert_trimmed_reads_to_fasta/fastq"
                        }
                    ],
                    "out": [
                        "#main/convert_trimmed_reads_to_fasta/fasta"
                    ],
                    "id": "#main/convert_trimmed_reads_to_fasta"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#main/count_processed_reads/number"
                        },
                        {
                            "source": "#main/length_filter/filtered_file",
                            "id": "#main/count_processed_reads/sequences"
                        }
                    ],
                    "out": [
                        "#main/count_processed_reads/count"
                    ],
                    "id": "#main/count_processed_reads"
                },
                {
                    "run": "#generate_checksum.cwl",
                    "when": "$(inputs.single == undefined)",
                    "scatter": "#main/hashsum_paired/input_file",
                    "in": [
                        {
                            "source": [
                                "#main/forward_reads",
                                "#main/reverse_reads"
                            ],
                            "id": "#main/hashsum_paired/input_file"
                        },
                        {
                            "source": "#main/single_reads",
                            "id": "#main/hashsum_paired/single"
                        }
                    ],
                    "out": [
                        "#main/hashsum_paired/hashsum"
                    ],
                    "id": "#main/hashsum_paired"
                },
                {
                    "run": "#generate_checksum.cwl",
                    "when": "$(inputs.single != undefined)",
                    "in": [
                        {
                            "source": "#main/single_reads",
                            "id": "#main/hashsum_single/input_file"
                        },
                        {
                            "source": "#main/single_reads",
                            "id": "#main/hashsum_single/single"
                        }
                    ],
                    "out": [
                        "#main/hashsum_single/hashsum"
                    ],
                    "id": "#main/hashsum_single"
                },
                {
                    "run": "#qc-filtering.cwl",
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#main/length_filter/input_file_format"
                        },
                        {
                            "source": "#main/qc_min_length",
                            "id": "#main/length_filter/min_length"
                        },
                        {
                            "source": "#main/convert_trimmed_reads_to_fasta/fasta",
                            "id": "#main/length_filter/seq_file"
                        },
                        {
                            "default": "qc_summary",
                            "id": "#main/length_filter/stats_file_name"
                        },
                        {
                            "source": "#main/overlap_reads/count_forward_submitted_reads",
                            "id": "#main/length_filter/submitted_seq_count"
                        }
                    ],
                    "out": [
                        "#main/length_filter/filtered_file",
                        "#main/length_filter/stats_summary_file"
                    ],
                    "id": "#main/length_filter"
                },
                {
                    "label": "Paired-end overlapping reads are merged",
                    "run": "#seqprep-subwf.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/overlap_reads/forward_reads"
                        },
                        {
                            "default": 70,
                            "id": "#main/overlap_reads/paired_reads_length_filter"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/overlap_reads/reverse_reads"
                        },
                        {
                            "source": "#main/single_reads",
                            "id": "#main/overlap_reads/single_reads"
                        }
                    ],
                    "out": [
                        "#main/overlap_reads/unzipped_single_reads",
                        "#main/overlap_reads/count_forward_submitted_reads",
                        "#main/overlap_reads/fastp_report"
                    ],
                    "id": "#main/overlap_reads"
                },
                {
                    "run": "#qc-stats.cwl",
                    "in": [
                        {
                            "source": "#main/length_filter/filtered_file",
                            "id": "#main/qc_stats/QCed_reads"
                        },
                        {
                            "source": "#main/count_processed_reads/count",
                            "id": "#main/qc_stats/sequence_count"
                        }
                    ],
                    "out": [
                        "#main/qc_stats/output_dir",
                        "#main/qc_stats/summary_out"
                    ],
                    "id": "#main/qc_stats"
                },
                {
                    "doc": "Low quality trimming (low quality ends and sequences with < quality scores\nless than 15 over a 4 nucleotide wide window are removed)\n",
                    "run": "#Trimmomatic-v0.36-SE.cwl",
                    "in": [
                        {
                            "default": "SE",
                            "id": "#main/trim_quality_control/end_mode"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/leading"
                        },
                        {
                            "default": 100,
                            "id": "#main/trim_quality_control/minlen"
                        },
                        {
                            "default": "33",
                            "id": "#main/trim_quality_control/phred"
                        },
                        {
                            "source": "#main/overlap_reads/unzipped_single_reads",
                            "id": "#main/trim_quality_control/reads1"
                        },
                        {
                            "default": "4:15",
                            "id": "#main/trim_quality_control/slidingwindow"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/trailing"
                        }
                    ],
                    "out": [
                        "#main/trim_quality_control/reads1_trimmed"
                    ],
                    "id": "#main/trim_quality_control"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep-subwf.cwl/forward_reads"
                },
                {
                    "type": "int",
                    "id": "#seqprep-subwf.cwl/paired_reads_length_filter"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep-subwf.cwl/reverse_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#seqprep-subwf.cwl/single_reads"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "outputSource": [
                        "#seqprep-subwf.cwl/count_submitted_reads/count",
                        "#seqprep-subwf.cwl/count_submitted_reads_single/count"
                    ],
                    "pickValue": "first_non_null",
                    "id": "#seqprep-subwf.cwl/count_forward_submitted_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#seqprep-subwf.cwl/filter_paired/json_report",
                    "id": "#seqprep-subwf.cwl/fastp_report"
                },
                {
                    "type": "File",
                    "outputSource": [
                        "#seqprep-subwf.cwl/unzip_merged_reads/unzipped_file",
                        "#seqprep-subwf.cwl/unzip_single_reads/unzipped_file"
                    ],
                    "pickValue": "first_non_null",
                    "id": "#seqprep-subwf.cwl/unzipped_single_reads"
                }
            ],
            "steps": [
                {
                    "run": "#count_lines.cwl",
                    "when": "$(inputs.single == undefined)",
                    "in": [
                        {
                            "default": 4,
                            "id": "#seqprep-subwf.cwl/count_submitted_reads/number"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/forward_reads",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads/sequences"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads/single"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/count_submitted_reads/count"
                    ],
                    "id": "#seqprep-subwf.cwl/count_submitted_reads"
                },
                {
                    "run": "#count_lines.cwl",
                    "when": "$(inputs.target_reads != undefined)",
                    "in": [
                        {
                            "default": 4,
                            "id": "#seqprep-subwf.cwl/count_submitted_reads_single/number"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/unzip_single_reads/unzipped_file",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads_single/sequences"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/count_submitted_reads_single/target_reads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/count_submitted_reads_single/count"
                    ],
                    "id": "#seqprep-subwf.cwl/count_submitted_reads_single"
                },
                {
                    "run": "#fastp.cwl",
                    "when": "$(inputs.single == undefined)",
                    "in": [
                        {
                            "default": false,
                            "id": "#seqprep-subwf.cwl/filter_paired/base_correction"
                        },
                        {
                            "default": false,
                            "id": "#seqprep-subwf.cwl/filter_paired/disable_trim_poly_g"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/forward_reads",
                            "id": "#seqprep-subwf.cwl/filter_paired/fastq1"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/reverse_reads",
                            "id": "#seqprep-subwf.cwl/filter_paired/fastq2"
                        },
                        {
                            "default": false,
                            "id": "#seqprep-subwf.cwl/filter_paired/force_polyg_tail_trimming"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/paired_reads_length_filter",
                            "id": "#seqprep-subwf.cwl/filter_paired/min_length_required"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/filter_paired/single"
                        },
                        {
                            "default": 8,
                            "id": "#seqprep-subwf.cwl/filter_paired/threads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/filter_paired/out_fastq1",
                        "#seqprep-subwf.cwl/filter_paired/out_fastq2",
                        "#seqprep-subwf.cwl/filter_paired/json_report"
                    ],
                    "id": "#seqprep-subwf.cwl/filter_paired"
                },
                {
                    "label": "Paired-end overlapping reads are merged",
                    "run": "#seqprep.cwl",
                    "when": "$(inputs.single == undefined)",
                    "in": [
                        {
                            "source": "#seqprep-subwf.cwl/filter_paired/out_fastq1",
                            "id": "#seqprep-subwf.cwl/overlap_reads/forward_reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/forward_reads",
                            "id": "#seqprep-subwf.cwl/overlap_reads/namefile"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/filter_paired/out_fastq2",
                            "id": "#seqprep-subwf.cwl/overlap_reads/reverse_reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/overlap_reads/single"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/overlap_reads/merged_reads",
                        "#seqprep-subwf.cwl/overlap_reads/forward_unmerged_reads",
                        "#seqprep-subwf.cwl/overlap_reads/reverse_unmerged_reads"
                    ],
                    "id": "#seqprep-subwf.cwl/overlap_reads"
                },
                {
                    "when": "$(inputs.target_reads != undefined)",
                    "run": "#multiple-gunzip.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#seqprep-subwf.cwl/unzip_merged_reads/reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/overlap_reads/merged_reads",
                            "id": "#seqprep-subwf.cwl/unzip_merged_reads/target_reads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/unzip_merged_reads/unzipped_file"
                    ],
                    "id": "#seqprep-subwf.cwl/unzip_merged_reads"
                },
                {
                    "run": "#multiple-gunzip.cwl",
                    "when": "$(inputs.target_reads != undefined)",
                    "in": [
                        {
                            "default": true,
                            "id": "#seqprep-subwf.cwl/unzip_single_reads/reads"
                        },
                        {
                            "source": "#seqprep-subwf.cwl/single_reads",
                            "id": "#seqprep-subwf.cwl/unzip_single_reads/target_reads"
                        }
                    ],
                    "out": [
                        "#seqprep-subwf.cwl/unzip_single_reads/unzipped_file"
                    ],
                    "id": "#seqprep-subwf.cwl/unzip_single_reads"
                }
            ],
            "id": "#seqprep-subwf.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.2",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf",
        "http://edamontology.org/EDAM_1.18.owl",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
